==> chicken_1.63.orig.tar.gz: chicken-1.63.orig/psyntax-bootstrap.scm <==
;;;; psyntax-bootstrap.scm - Generate expanded psyntax-chicken.pp - felix
;
; Copyright (c) 2000-2004, Felix L. Winkelmann
; All rights reserved.
;
; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
; conditions are met:
;
;   Redistributions of source code must retain the above copyright notice, this list of conditions and the following
;     disclaimer. 
;   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
;     disclaimer in the documentation and/or other materials provided with the distribution. 
;   Neither the name of the author nor the names of its contributors may be used to endorse or promote
;     products derived from this software without specific prior written permission. 
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
; OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
; AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
; CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
; OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.
;
; Send bugs, suggestions and ideas to: 
;
; felix@call-with-current-continuation.org
;
; Felix L. Winkelmann
; Unter den Gleichen 1
; 37130 Gleichen
; Germany


(define eval
  (let ([eval eval])
    (lambda (x . env)
      (apply 
       eval 
       (if (and-let* ([(pair? x)] [a (car x)])
	     (string? a)
	     (string=? "noexpand" a) )
	   (cadr x) 
	   x)
       env) ) ) )

(define ##syncase#current-export-prefix #f)
(define ##syncase#properties (make-vector 3001 '()))

(define (putprop s k x)
  (let ([props (##sys#hash-table-ref ##syncase#properties s)])
    (if props
	(let ([a (assq props k)])
	  (if a
	      (##sys#setslot a 1 x)
	      (##sys#hash-table-set! ##syncase#properties s (cons (cons k x) props)) ) )
	(##sys#hash-table-set! ##syncase#properties s (list (cons k x))) ) ) )

(define (getprop s k)
  (and-let* ([props (##sys#hash-table-ref ##syncase#properties s)]
	     [a (assq k props)] )
    (cdr a) ) )

(define (remprop s k)
  (and-let* ([props (##sys#hash-table-ref ##syncase#properties s)])
    (let loop ([ps props] [prev #f])
      (unless (null? ps)
	(let ([a (##sys#slot ps 0)]
	      [r (##sys#slot ps 1)] )
	  (if (eq? k (##sys#slot a 0))
	      (if prev
		  (##sys#setslot prev 1 r)
		  (##sys#hash-table-set! ##syncase#properties s r) )
	      (loop r ps) ) ) ) ) ) )

(print "bootstrapping psyntax.pp ...")
(load "psyntax.pp")

(define (expand-file file outfile)
  (with-input-from-file file
    (lambda ()
      (call-with-output-file outfile
	(lambda (out)
	  (for-each
	   (lambda (x)
	     (pretty-print (sc-expand x) out) 
	     (newline out) ) 
	   (read-file) ) ) ) ) ) )

(print "expanding psyntax.scm to psyntax-chicken.pp ...")
(expand-file "psyntax.scm" "psyntax-chicken.pp")

==> chicken-1.89.tar.gz: chicken-1.89/psyntax-bootstrap.scm <==
;;;; psyntax-bootstrap.scm - Generate expanded psyntax-chicken.pp - felix
;
; Copyright (c) 2000-2004, Felix L. Winkelmann
; All rights reserved.
;
; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
; conditions are met:
;
;   Redistributions of source code must retain the above copyright notice, this list of conditions and the following
;     disclaimer. 
;   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
;     disclaimer in the documentation and/or other materials provided with the distribution. 
;   Neither the name of the author nor the names of its contributors may be used to endorse or promote
;     products derived from this software without specific prior written permission. 
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
; OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
; AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
; CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
; OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.
;
; Send bugs, suggestions and ideas to: 
;
; felix@call-with-current-continuation.org
;
; Felix L. Winkelmann
; Unter den Gleichen 1
; 37130 Gleichen
; Germany


(define eval
  (let ([eval eval])
    (lambda (x . env)
      (apply 
       eval 
       (if (and-let* ([(pair? x)] [a (car x)] [(string? a)])
	     (string=? "noexpand" a) )
	   (cadr x) 
	   x)
       env) ) ) )

(define ##syncase#current-export-prefix #f)
(define ##syncase#properties (make-vector 3001 '()))

(define (putprop s k x)
  (let ([props (##sys#hash-table-ref ##syncase#properties s)])
    (if props
	(let ([a (assq props k)])
	  (if a
	      (##sys#setslot a 1 x)
	      (##sys#hash-table-set! ##syncase#properties s (cons (cons k x) props)) ) )
	(##sys#hash-table-set! ##syncase#properties s (list (cons k x))) ) ) )

(define (getprop s k)
  (and-let* ([props (##sys#hash-table-ref ##syncase#properties s)]
	     [a (assq k props)] )
    (cdr a) ) )

(define (remprop s k)
  (and-let* ([props (##sys#hash-table-ref ##syncase#properties s)])
    (let loop ([ps props] [prev #f])
      (unless (null? ps)
	(let ([a (##sys#slot ps 0)]
	      [r (##sys#slot ps 1)] )
	  (if (eq? k (##sys#slot a 0))
	      (if prev
		  (##sys#setslot prev 1 r)
		  (##sys#hash-table-set! ##syncase#properties s r) )
	      (loop r ps) ) ) ) ) ) )

(print "bootstrapping psyntax.pp ...")
(load "psyntax.pp")

(define (expand-file file outfile)
  (with-input-from-file file
    (lambda ()
      (call-with-output-file outfile
	(lambda (out)
	  (for-each
	   (lambda (x)
	     (pretty-print (sc-expand x) out) 
	     (newline out) ) 
	   (read-file) ) ) ) ) ) )

(print "expanding psyntax.scm to psyntax-chicken.pp ...")
(expand-file "psyntax.scm" "psyntax-chicken.pp")
